:orphan:

Reference
=========

Technical reference material including APIs and release notes.

.. toctree::
    :caption: Reference

    Releases <https://github.com/epics-containers/python3-pip-skeleton/releases>
    Index <genindex.html#http://>

..
    Index link above is a hack to make genindex.html a relative link
    https://stackoverflow.com/a/31820846
